@@ -76,12 +76,12 @@ test_that("bind methods work properly", {
   a <- 1:10
   b <- set_errors(a, a)
 
-  x <- rbind(a, a)
-  y <- rbind(b, b)
+  x <- rbind(x=a, y=a)
+  y <- rbind(x=b, y=b)
   expect_equal(as.numeric(x), as.numeric(y))
   expect_equal(rep(a, each=2), errors(y))
-  expect_equal(rownames(x), c("a", "a"))
-  expect_equal(rownames(y), c("b", "b"))
+  expect_equal(rownames(x), c("x", "y"))
+  expect_equal(rownames(y), c("x", "y"))
   x <- rbind(rbind(a, a), a)
   y <- rbind(rbind(b, b), b)
   expect_equal(as.numeric(x), as.numeric(y))
@@ -95,12 +95,12 @@ test_that("bind methods work properly", {
   expect_equal(rownames(x), c("a", "a", "a"))
   expect_equal(rownames(y), c("b", "b", "b"))
 
-  x <- cbind(a, a)
-  y <- cbind(b, b)
+  x <- cbind(x=a, y=a)
+  y <- cbind(x=b, y=b)
   expect_equal(as.numeric(x), as.numeric(y))
   expect_equal(rep(a, 2), errors(y))
-  expect_equal(colnames(x), c("a", "a"))
-  expect_equal(colnames(y), c("b", "b"))
+  expect_equal(colnames(x), c("x", "y"))
+  expect_equal(colnames(y), c("x", "y"))
   x <- cbind(cbind(a, a), a)
   y <- cbind(cbind(b, b), b)
   expect_equal(as.numeric(x), as.numeric(y))
